<?php
/*                                                                                                                                                       
   ;;;;;;;;;;;;;                               ;;;;;;;;;;;;           
	;;;;;;;;;;;;;;;.                     ,;;;;;;;;;;;;;;;            
	 ;;;;;;;;;;;;;;;;;                 ;;;;;;;;;;;;;;;;;             
	   ;;;;;;;;;;;;;;;;;            .;;;;;;;;;;;;;;;;;               
				 :;;;;;;;;         ;;;;;;;;:                         
					  ;;;;;      ,;;;;:                              
						 ;;;.   ;;;;                                 
						   ;;  ,;;                                   
							;; ;;                                    
							 ;;;                                     
							 ;;; 

	^^ Title : Cookie consent banner - eu law
	^^ Create : 2020-10-19
	^^ For PS version 1.4, 1.5, 1.6
	^^ Copyright : EAGLEMEDIA.de 
    
    * https://www.it-recht-kanzlei.de/cookie-consent-bedarf-huerden.html
*/

	# Reports for either E_ERROR | E_WARNING | 
	# E_NOTICE | Any Error
	#
	#ini_set("display_startup_errors", 1);
	#ini_set("display_errors", 1);
	#error_reporting(E_ALL);

if (!defined('_PS_VERSION_')) 
	exit;
	
class cookieBanner extends Module
{

	public function __construct()
	{
		$this->name = 'cookiebanner';
		$this->tab = 'front_office_features';
		$this->version = '1.4.3';
		$this->author = 'EAGLEMEDIA.de';
        $this->need_instance = 0;

        $this->bootstrap = true; // styles
		parent::__construct();

		$this->displayName = $this->l('Cookie consent tool - eu law');
		$this->description = $this->l('Adds a cookie consent tool in top of the page.');
	}

	public function install()
	{
	    $text = $this->l('In order to improve the functionality of our website, we collect technical anonymous information about you, including tracking technologies from third parties, in order to offer their services and to display advertising in line with the interests of the users. I agree to this and can revoke my consent at any time with effect for the future. You can find detailed information about the technologies we use at:');
	
	    Configuration::updateValue('COOKIEBANNER_IMGNAME', 'cookiebanner.jpg');
		Configuration::updateValue('COOKIEBANNER_LINK', 'https://eaglemedia.de');        
		Configuration::updateValue('COOKIEBANNER_ISEE', 'show' );
		Configuration::updateValue('COOKIEBANNER_TEXT', $text );
        Configuration::updateValue('COOKIEBANNER_PPL_ID', '0');
		Configuration::updateValue('COOKIEBANNER_TRACKERCODE_GA', 'UA..' ); 
        Configuration::updateValue('COOKIEBANNER_BANNER', '#1183f3');
        Configuration::updateValue('COOKIEBANNER_BANNER_TEXT', '#fafafa');
        Configuration::updateValue('COOKIEBANNER_BUTTON', '');
        Configuration::updateValue('COOKIEBANNER_BUTTON_BORDER', '#fafafa');
        Configuration::updateValue('COOKIEBANNER_BUTTON_TEXT', '#fafafa');
        Configuration::updateValue('COOKIEBANNER_PAGE_OVERLAY', 'show');
        Configuration::updateValue('COOKIEBANNER_BUTTON_TRIANGLE', 'top');
        
		if( !parent::install()
		OR  !$this->registerHook('top')	
		OR  !$this->registerHook('header')
		OR  !$this->registerHook('BackOfficeHeader') )
			return false;
		return true;
	}
	
	public function uninstall()
	{
        $extensions = array('.gif', '.jpg', '.jpeg', '.png', '.webp');
        foreach($extensions as $extension)
            $this->deleteUploadetImages($extension);
            
	 	if( !parent::uninstall() 
		OR  !Configuration::deleteByName('COOKIEBANNER_IMGNAME')
		OR  !Configuration::deleteByName('COOKIEBANNER_LINK')       
		OR  !Configuration::deleteByName('COOKIEBANNER_ISEE')
		OR  !Configuration::deleteByName('COOKIEBANNER_TEXT')
        OR  !Configuration::deleteByName('COOKIEBANNER_PPL_ID')
		OR  !Configuration::deleteByName('COOKIEBANNER_TRACKERCODE_GA')
        OR  !Configuration::deleteByName('COOKIEBANNER_BANNER')
        OR  !Configuration::deleteByName('COOKIEBANNER_BANNER_TEXT')
        OR  !Configuration::deleteByName('COOKIEBANNER_BUTTON')
        OR  !Configuration::deleteByName('COOKIEBANNER_BUTTON_BORDER')
        OR  !Configuration::deleteByName('COOKIEBANNER_BUTTON_TEXT')
        OR  !Configuration::deleteByName('COOKIEBANNER_PAGE_OVERLAY')
        OR  !Configuration::deleteByName('COOKIEBANNER_BUTTON_TRIANGLE') )
	 		return false;
	 	return true;
	}

	private function deleteUploadetImages($extension)
	{
		if( file_exists(_PS_MODULE_DIR_.$this->name.'/img/cookiebanner_upload_'.$extension) )
			unlink(_PS_MODULE_DIR_.$this->name.'/img/cookiebanner_upload_'.$extension);
	}

	public function postProcess()
	{ 
		$errors = false;
		if( Tools::isSubmit('cookieCross') )
		{		
            // image handling	
			if( isset($_FILES['banner_img']) AND 
                isset($_FILES['banner_img']['tmp_name']) AND 
                !empty($_FILES['banner_img']['tmp_name']) )	{
	
                
                $path_parts = pathinfo($_FILES['banner_img']['name']);
                $extension = '.'.strtolower($path_parts['extension']);            
				
				if( $error = checkImage($_FILES['banner_img'], Tools::convertBytes(ini_get('upload_max_filesize'))) )
				    $errors .= $error."<br>\n";	                

                // move_uploaded_file.. if the destination file already exists, it will be overwritten
				else
                if( !move_uploaded_file($_FILES['banner_img']['tmp_name'], _PS_MODULE_DIR_.$this->name.'/img/cookiebanner_upload_'.$extension) )	
				    $errors .= $this->l('Error move uploaded file')."<br>\n";			


                
					
				if( !$errors ) {
                    // get image path
					$this->banner_img = Tools::getMediaServer($this->name)._MODULE_DIR_.$this->name.'/img/cookiebanner_upload_'.$extension;	
                    // update default image
					Configuration::updateValue('COOKIEBANNER_IMGNAME', 'cookiebanner_upload_'.$extension);
				}	
			}
			
			if ( !empty(Tools::getValue('banner_link')) AND (Tools::getValue('banner_link') != 'https://eaglemedia.de') ) {
			    Configuration::updateValue('COOKIEBANNER_LINK', Tools::getValue('banner_link'));  
            }
            else { $errors .= $this->l('Link image is incorrect')."<br>\n"; }
            				
			
			    Configuration::updateValue('COOKIEBANNER_ISEE', Tools::getValue('banner_isee'));
            
			
			if ( !empty(Tools::getValue('banner_text')) ) {
			    Configuration::updateValue('COOKIEBANNER_TEXT', Tools::getValue('banner_text')); 
            }
            else { $errors .= $this->l('Banner text is empty')."<br>\n"; }
				
			if ( !empty(Tools::getValue('banner_pplink_id')) || (int)Configuration::get("COOKIEBANNER_PPL_ID") != 0 ) {
                Configuration::updateValue('COOKIEBANNER_PPL_ID', trim(Tools::getValue('banner_pplink_id'))); 
            }
            else { $errors .= $this->l('Link private police is empty')."<br>\n"; }
				
			if ( !empty(Tools::getValue('banner_gacode')) AND (Tools::getValue('banner_gacode') != 'UA..') ) {
			    Configuration::updateValue('COOKIEBANNER_TRACKERCODE_GA', Tools::getValue('banner_gacode'));
            }
            else { $errors .= $this->l('Google code is incorrect')."<br>\n"; }
            
	
                Configuration::updateValue('COOKIEBANNER_PAGE_OVERLAY', trim(Tools::getValue('banner_page_overlay')));
                Configuration::updateValue('COOKIEBANNER_BANNER', trim(Tools::getValue('banner_color')));		
                Configuration::updateValue('COOKIEBANNER_BANNER_TEXT', trim(Tools::getValue('banner_color_text')));
                Configuration::updateValue('COOKIEBANNER_BUTTON', trim(Tools::getValue('button_color')));
                Configuration::updateValue('COOKIEBANNER_BUTTON_BORDER', trim(Tools::getValue('button_color_border')));		
                Configuration::updateValue('COOKIEBANNER_BUTTON_TEXT', trim(Tools::getValue('button_color_text')));
                Configuration::updateValue('COOKIEBANNER_BUTTON_TRIANGLE', trim(Tools::getValue('button_triangle')));
                

            
			if( $errors ) {
				return '
                <div class="alert alert-danger error">
                    '.((ip2long(_PS_VERSION_) >= ip2long('1.4.0.0')) ? '<button type="button" class="close" data-dismiss="alert">×</button>' : '').'
                    '.$errors.'</div>';	
            }
			else
				return $this->displayConfirmation($this->l('Settings updated successfully'));					
		}		
	}

	public function getContent()
	{
	    return $this->postProcess().$this->renderForm();
	}
	
	public function renderForm()
	{
	    global $protocol_content;		

	    $fields_form = '
    <div class="cookiebanner text-center">
        '.$this->l('Have a look at my modules for PrestaShop').' -
        <a href="https://eaglemedia.de/cms.php?s=prestashop-module" target="_blank">MODULE</a>
        <p class="clear"> </p>
        '.$this->l('Made with').' <i class="icon-heart"></i> '.$this->l('by').'
        <a href="http://eaglemedia.de" target="_blank">EAGLEMEDIA</a>
        <p class="clear"><br/> </p>
            
        <form action="https://www.paypal.com/donate" method="post" target="_blank">
            <input type="hidden" name="hosted_button_id" value="ALLRFT5RZJVHN" />
            <input type="image" src="https://www.paypalobjects.com/de_DE/DE/i/btn/btn_donateCC_LG.gif" 
                   border="0" name="submit" title="PayPal - The safer, easier way to pay online!" alt="Donate with PayPal button" />
            
            <img alt="" border="0" src="https://www.paypal.com/de_DE/i/scr/pixel.gif" width="1" height="1" />
        </form>
        <p class="clear"><br/><br/> </p>	
    </div>

	<form action="'.$_SERVER['REQUEST_URI'].'" method="post" enctype="multipart/form-data" class="cookiebanner bootstrap panel">
		<fieldset>
			<legend>
                <a href="https://eaglemedia.de" target="_blank"><img src="'.$this->_path.'logo.png" alt="" title="'.$this->author.'" /></a> 
                '.$this->l('Configuration').'</legend>';
			
		if (Configuration::get('COOKIEBANNER_IMGNAME'))
		{
			$fields_form .= '            
            <h4>'.Configuration::get('COOKIEBANNER_IMGNAME').'</h4>
            
			<img src="'.$protocol_content.$this->_path.'img/'.Configuration::get('COOKIEBANNER_IMGNAME').'" title="'.$this->l('Banner image').'" alt="'.$this->l('Image').'" />';
		}
		else
			$this->l('no image'); 
        
        
        // create cms link options       
        $firstOption = array(
            array('id_cms' => 0, 'meta_title' => '---' )
        );
        $cmsOptions  = CMS::listCms();
        $cmsLinkDetails = array_merge($firstOption, $cmsOptions);
        
        $cmsOptionDetail ='';        
        foreach($cmsLinkDetails as $cmsLinkDetail) {
            $cmsOptionDetail .= '
<option data-id-cms="'.$cmsLinkDetail['id_cms'].'" onClick="chooseCmsLink('.$cmsLinkDetail['id_cms'].')"'.(((int)Configuration::get("COOKIEBANNER_PPL_ID") == (int)$cmsLinkDetail['id_cms']) ? ' class="js_cms_select" selected' : '').'>'.$cmsLinkDetail['meta_title'].'</option>';
        };
        
         
			
	    $fields_form .= '            
				<p class="clear"><br/><br/> </p>                
                
                
            <h4>'.$this->l('Content').'</h4>				

			<label for="banner_img">'.$this->l('Change image').'</label>
			<div class="margin-form">	
				<input type="file" name="banner_img" id="banner_img" class="btn btn-default" />
                <p class="clear">'.$this->l('Create images with extensions | .gif | .jpg | .jpeg | .png | .webp |').'</p>
				<p class="clear"> </p>	
							
			</div>
			<label for="banner_link">'.$this->l('Image link').'</label>
			<div class="margin-form">
				<input type="text" name="banner_link" value="'.Configuration::get('COOKIEBANNER_LINK').'" />		
				<p class="clear">'.$this->l('Link with \' http \' or.. \' https \'').'</p>				
				<p class="clear"> </p>			
			</div>					

			<div class="margin-form">
			    <input type="hidden" name="banner_isee" id="banner_isee" value="'.Configuration::get('COOKIEBANNER_ISEE').'" />
				<input type="checkbox" onclick="iseeCheckbox(\'#banner_isee\')" '.(Configuration::get('COOKIEBANNER_ISEE') !='hidden' ? 'checked' : '' ).' />
				<p class="label">'.$this->l('Display logo in front?').'</p>					
				<p class="clear"><br/><br/> </p>		
			</div>
				
			<label for="banner_link">'.$this->l('Banner text').'</label>
			<div class="margin-form">
				<textarea name="banner_text" rows="5" />'.Configuration::get('COOKIEBANNER_TEXT').'</textarea>	
				<p class="clear">'.$this->l('Free text ...').'</p>
				<p class="clear"> </p>			
			</div>            
            
 			<label for="banner_pplink">'.$this->l('Privat police link').'</label>
			<div class="margin-form">
                <input type="hidden" name="banner_pplink_id" id="pplink_id" value="" />
				<select id="js_cms_select">
                    '.$cmsOptionDetail.'
                    
                </select>			
				<p class="clear"><br/><br/> </p>		
			</div>	
            
			<label>'.$this->l('Page Overlay').'</label>
			<div class="margin-form">  
			    <input type="hidden" name="banner_page_overlay" id="banner_page_overlay" value="'.Configuration::get('COOKIEBANNER_PAGE_OVERLAY').'" />
				<input type="checkbox" onclick="povCheckbox(\'#banner_page_overlay\')" '.(Configuration::get('COOKIEBANNER_PAGE_OVERLAY') !='hidden' ? 'checked' : '' ).' />
				<p class="label">'.$this->l('Display overlay in front?').'</p>					
				<p class="clear"><br/> </p>				
			</div>
            
			<label>'.$this->l('Triangle Button').'</label>
			<div class="margin-form">  
			    <input type="hidden" name="button_triangle" id="button_triangle" value="'.Configuration::get('COOKIEBANNER_BUTTON_TRIANGLE').'" />
				<input type="checkbox" onclick="triangleCheckbox(\'#button_triangle\')" '.(Configuration::get('COOKIEBANNER_BUTTON_TRIANGLE') !='top' ? 'checked' : '' ).' />
				<p class="label">'.$this->l('Bottom in front?').'</p>					
				<p class="clear"><br/><br/> </p>				
			</div>
          
            
            
            
            <h4>'.$this->l('Style').'</h4>           
            
			<label>'.$this->l('Banner').'</label>
			<div class="margin-form">
				<input type="text" name="banner_color" value="'.Configuration::get("COOKIEBANNER_BANNER").'"
                       data-hex="true" 
                       class="mColorPickerInput mColorPicker"                       
                       style="background:'.Configuration::get("COOKIEBANNER_BANNER").'"
                       id="color_0" />
                       <span style="cursor:pointer;" id="icp_color_0" class="mColorPickerTrigger input-group-addon" data-mcolorpicker="true">
                            <img src="../img/admin/color.png"></span>			
			</div>   
            
			<label>'.$this->l('Banner Text').'</label>
			<div class="margin-form">
				<input type="text" name="banner_color_text" value="'.Configuration::get("COOKIEBANNER_BANNER_TEXT").'"
                       data-hex="true" 
                       class="mColorPickerInput mColorPicker"
                       style="background:'.Configuration::get("COOKIEBANNER_BANNER_TEXT").'"
                       id="color_1" />
                       <span style="cursor:pointer;" id="icp_color_1" class="mColorPickerTrigger input-group-addon" data-mcolorpicker="true">
                            <img src="../img/admin/color.png"></span>		
			</div>  
            
			<label>'.$this->l('Button').'</label>
			<div class="margin-form">
				<input type="text" name="button_color" value="'.Configuration::get("COOKIEBANNER_BUTTON").'" 
                       data-hex="true" 
                       class="mColorPickerInput mColorPicker"
                       style="background:'.Configuration::get("COOKIEBANNER_BUTTON").'"
                       id="color_2" />
                       <span style="cursor:pointer;" id="icp_color_2" class="mColorPickerTrigger input-group-addon" data-mcolorpicker="true">
                            <img src="../img/admin/color.png"></span>			
			</div>
            
			<label>'.$this->l('Button Border').'</label>
			<div class="margin-form">
				<input type="text" name="button_color_border" value="'.Configuration::get("COOKIEBANNER_BUTTON_BORDER").'" 
                       data-hex="true" 
                       class="mColorPickerInput mColorPicker"
                       style="background:'.Configuration::get("COOKIEBANNER_BUTTON_BORDER").'"
                       id="color_3" />
                       <span style="cursor:pointer;" id="icp_color_3" class="mColorPickerTrigger input-group-addon" data-mcolorpicker="true">
                            <img src="../img/admin/color.png"></span>			
			</div>
            
			<label>'.$this->l('Button Text').'</label>
			<div class="margin-form">
				<input type="text" name="button_color_text" value="'.Configuration::get("COOKIEBANNER_BUTTON_TEXT").'"  
                       data-hex="true" 
                       class="mColorPickerInput mColorPicker"
                       style="background:'.Configuration::get("COOKIEBANNER_BUTTON_TEXT").'"
                       id="color_4" />
                       <span style="cursor:pointer;" id="icp_color_4" class="mColorPickerTrigger input-group-addon" data-mcolorpicker="true">
                            <img src="../img/admin/color.png"></span>	
                            
                       <p class="clear"><br/><br/> </p>
			</div>        

                        
  
        
        
            <h4>'.$this->l('Tracker').'</h4>       

			<label for="banner_gacode">'.$this->l('Google Analytics code').'</label>
			<div class="margin-form">
				<input type="text" name="banner_gacode" value="'.Configuration::get('COOKIEBANNER_TRACKERCODE_GA').'" />		
				<p class="clear">'.$this->l('Fill this format : UA-12345678-1').'</p>			
			</div>            
			 
			<button type="submit" value="1" id="module_form_submit_btn" name="cookieCross" 
			     class="btn btn-default pull-right" style="margin:0 auto;">
			     <i class="process-icon-save"></i>
			     '.$this->l('Update').'						
			</button>               
			<p class="clear"><br/> </p>';
				
		if( ip2long(_PS_VERSION_)  < ip2long('1.5.0.0') )				
			echo '
			<p class="clear required">'.$this->l('Add plugin: /js/jquery.cookie-plugin.js').'</p>';	
	  
	    $fields_form .= '			
		</fieldset>
	</form>
	<script>
	    var iseeFlag = '.(Configuration::get('COOKIEBANNER_ISEE') !='hidden' ? 'false' : 'true' ).';
        var povFlag = '.(Configuration::get('COOKIEBANNER_PAGE_OVERLAY') !='hidden' ? 'false' : 'true' ).';
        var triFlag = '.(Configuration::get('COOKIEBANNER_BUTTON_TRIANGLE') !='bottom' ? 'false' : 'true' ).';
	</script>';
			
		return $fields_form;
	}


	public function hookTop( $params )
	{
		global $smarty, $protocol_content;
        
        $objLink ='';
        $cmsLink ='';
        if ((int)Configuration::get("COOKIEBANNER_PPL_ID") > 0) {
            $objLink = new Link();
            $cmsLink = $objLink->getCMSLink((int)Configuration::get("COOKIEBANNER_PPL_ID"));
        }
		
		$smarty->assign(
		    array(
			  'ps_version' => (ip2long(_PS_VERSION_) <= ip2long('1.6.1.10') ? 'deprecated' : ''),
              'banner_path' => $this->_path,
			  'banner_image' => (ip2long(_PS_VERSION_) < ip2long('1.5.0.0') ? $protocol_content.$this->_path.'img/'.Configuration::get('COOKIEBANNER_IMGNAME') : $this->_path.'img/'.Configuration::get('COOKIEBANNER_IMGNAME')),
			  'banner_link' => Configuration::get('COOKIEBANNER_LINK'),
			  'banner_text' => Configuration::get('COOKIEBANNER_TEXT'),
			  'banner_pplink' => ($cmsLink ? $cmsLink : Configuration::get('COOKIEBANNER_LINK')),			  
			  'banner_isee' => Configuration::get('COOKIEBANNER_ISEE'),
              'banner_page_overlay' => Configuration::get("COOKIEBANNER_PAGE_OVERLAY"),
              'banner_color' => Configuration::get("COOKIEBANNER_BANNER"),
              'banner_color_text' => Configuration::get("COOKIEBANNER_BANNER_TEXT"),             
              'button_color' => Configuration::get("COOKIEBANNER_BUTTON"),
              'button_color_border' => Configuration::get("COOKIEBANNER_BUTTON_BORDER"),
              'button_color_text' => Configuration::get("COOKIEBANNER_BUTTON_TEXT"),
              'button_triangle_pos' => Configuration::get("COOKIEBANNER_BUTTON_TRIANGLE"),
              'trackercode_ga' => Configuration::get('COOKIEBANNER_TRACKERCODE_GA'),            
		    )
		);

		return $this->display(__FILE__, 'views/templates/front/cookiebanner.tpl');
	}
	
	public function hookHeader()
	{  
	
		if( ip2long(_PS_VERSION_) >= ip2long('1.4.0.0') 
		AND ip2long(_PS_VERSION_) <= ip2long('1.6.1.10') )
		{
			$lib  = '
		<link type="text/css" rel="stylesheet" href="'.($this->_path.'css/cookiebanner.css').'" />
		<script type="text/javascript" src="'.__PS_BASE_URI__.'modules/'.$this->name.'/js/jquery.cookie.js"></script>
		<script type="text/javascript" src="'.($this->_path.'js/cookiebanner.js').'"></script>
			';
			
			return $lib;
		}
		
		if( ip2long(_PS_VERSION_) > ip2long('1.6.1.10') )
		{
	        $this->context->controller->addCSS($this->_path.'css/cookiebanner.css', 'all');
			$this->context->controller->addJqueryPlugin(array('cooki-plugin'));
			$this->context->controller->addJS($this->_path.'js/cookiebanner.js');
		}
	}
	
	public function hookBackOfficeHeader()
	{    

		if ( ip2long(_PS_VERSION_) >= ip2long('1.4.0.0') 
		 AND ip2long(_PS_VERSION_)  < ip2long('1.5.0.0') )
		{
			$lib  = '
		<link type="text/css" rel="stylesheet" href="'.($this->_path.'css/cookiebanner_bo.css').'" />
        <link type="text/css" rel="stylesheet" href="'.(__PS_BASE_URI__.'js/jquery/plugins/jquery.colorpicker.js').'" />
		<link type="text/css" rel="stylesheet" href="'.($this->_path.'js/cookiebanner_bo.js').'" />
			';
			
			return $lib;
		}
		
		if ( ip2long(_PS_VERSION_) >= ip2long('1.5.0.0') )
		{ 
            if (method_exists($this->context->controller, 'addJquery'))
                $this->context->controller->addJquery();
            
	        $this->context->controller->addCSS($this->_path.'css/cookiebanner_bo.css', 'all');
            $this->context->controller->addJS(__PS_BASE_URI__.'js/jquery/plugins/jquery.colorpicker.js');	
			$this->context->controller->addJS($this->_path.'js/cookiebanner_bo.js');	
		}
	}
}
